@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.webrisk_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -160,9 +171,9 @@ class WebRiskServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WebRiskServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web risk service client.
@@ -206,13 +217,13 @@ class WebRiskServiceAsyncClient:
 
     async def compute_threat_list_diff(
         self,
-        request: Union[webrisk.ComputeThreatListDiffRequest, dict] = None,
+        request: Optional[Union[webrisk.ComputeThreatListDiffRequest, dict]] = None,
         *,
-        threat_type: webrisk.ThreatType = None,
-        version_token: bytes = None,
-        constraints: webrisk.ComputeThreatListDiffRequest.Constraints = None,
+        threat_type: Optional[webrisk.ThreatType] = None,
+        version_token: Optional[bytes] = None,
+        constraints: Optional[webrisk.ComputeThreatListDiffRequest.Constraints] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.ComputeThreatListDiffResponse:
         r"""Gets the most recent threat list diffs. These diffs
@@ -241,7 +252,7 @@ class WebRiskServiceAsyncClient:
 
                 # Initialize request argument(s)
                 request = webrisk_v1.ComputeThreatListDiffRequest(
-                    threat_type="UNWANTED_SOFTWARE",
+                    threat_type="SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
                 )
 
                 # Make the request
@@ -251,12 +262,14 @@ class WebRiskServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest, dict]):
+            request (Optional[Union[google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest, dict]]):
                 The request object. Describes an API diff request.
             threat_type (:class:`google.cloud.webrisk_v1.types.ThreatType`):
                 Required. The threat list to update.
                 Only a single ThreatType should be
-                specified.
+                specified per request. If you want to
+                handle multiple ThreatTypes, you must
+                make one request per ThreatType.
 
                 This corresponds to the ``threat_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -344,12 +357,12 @@ class WebRiskServiceAsyncClient:
 
     async def search_uris(
         self,
-        request: Union[webrisk.SearchUrisRequest, dict] = None,
+        request: Optional[Union[webrisk.SearchUrisRequest, dict]] = None,
         *,
-        uri: str = None,
-        threat_types: Sequence[webrisk.ThreatType] = None,
+        uri: Optional[str] = None,
+        threat_types: Optional[MutableSequence[webrisk.ThreatType]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchUrisResponse:
         r"""This method is used to check whether a URI is on a
@@ -377,7 +390,7 @@ class WebRiskServiceAsyncClient:
                 # Initialize request argument(s)
                 request = webrisk_v1.SearchUrisRequest(
                     uri="uri_value",
-                    threat_types="UNWANTED_SOFTWARE",
+                    threat_types=['SOCIAL_ENGINEERING_EXTENDED_COVERAGE'],
                 )
 
                 # Make the request
@@ -387,7 +400,7 @@ class WebRiskServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.webrisk_v1.types.SearchUrisRequest, dict]):
+            request (Optional[Union[google.cloud.webrisk_v1.types.SearchUrisRequest, dict]]):
                 The request object. Request to check URI entries against
                 threatLists.
             uri (:class:`str`):
@@ -397,7 +410,7 @@ class WebRiskServiceAsyncClient:
                 This corresponds to the ``uri`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[google.cloud.webrisk_v1.types.ThreatType]`):
+            threat_types (:class:`MutableSequence[google.cloud.webrisk_v1.types.ThreatType]`):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
@@ -465,12 +478,12 @@ class WebRiskServiceAsyncClient:
 
     async def search_hashes(
         self,
-        request: Union[webrisk.SearchHashesRequest, dict] = None,
+        request: Optional[Union[webrisk.SearchHashesRequest, dict]] = None,
         *,
-        hash_prefix: bytes = None,
-        threat_types: Sequence[webrisk.ThreatType] = None,
+        hash_prefix: Optional[bytes] = None,
+        threat_types: Optional[MutableSequence[webrisk.ThreatType]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchHashesResponse:
         r"""Gets the full hashes that match the requested hash
@@ -497,7 +510,7 @@ class WebRiskServiceAsyncClient:
 
                 # Initialize request argument(s)
                 request = webrisk_v1.SearchHashesRequest(
-                    threat_types="UNWANTED_SOFTWARE",
+                    threat_types=['SOCIAL_ENGINEERING_EXTENDED_COVERAGE'],
                 )
 
                 # Make the request
@@ -507,19 +520,22 @@ class WebRiskServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.webrisk_v1.types.SearchHashesRequest, dict]):
+            request (Optional[Union[google.cloud.webrisk_v1.types.SearchHashesRequest, dict]]):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
             hash_prefix (:class:`bytes`):
                 A hash prefix, consisting of the most
                 significant 4-32 bytes of a SHA256 hash.
                 For JSON requests, this field is
-                base64-encoded.
+                base64-encoded. Note that if this
+                parameter is provided by a URI, it must
+                be encoded using the web safe base64
+                variant (RFC 4648).
 
                 This corresponds to the ``hash_prefix`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (:class:`Sequence[google.cloud.webrisk_v1.types.ThreatType]`):
+            threat_types (:class:`MutableSequence[google.cloud.webrisk_v1.types.ThreatType]`):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
@@ -587,12 +603,12 @@ class WebRiskServiceAsyncClient:
 
     async def create_submission(
         self,
-        request: Union[webrisk.CreateSubmissionRequest, dict] = None,
+        request: Optional[Union[webrisk.CreateSubmissionRequest, dict]] = None,
         *,
-        parent: str = None,
-        submission: webrisk.Submission = None,
+        parent: Optional[str] = None,
+        submission: Optional[webrisk.Submission] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.Submission:
         r"""Creates a Submission of a URI suspected of containing phishing
@@ -601,8 +617,9 @@ class WebRiskServiceAsyncClient:
         `Google's Social Engineering
         lists <https://support.google.com/webmasters/answer/6350487/>`__
         in order to protect users that could get exposed to this threat
-        in the future. Only projects with CREATE_SUBMISSION_USERS
-        visibility can use this method.
+        in the future. Only allowlisted projects can use this method
+        during Early Access. Please reach out to Sales or your customer
+        engineer to obtain access.
 
         .. code-block:: python
 
@@ -635,7 +652,7 @@ class WebRiskServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.webrisk_v1.types.CreateSubmissionRequest, dict]):
+            request (Optional[Union[google.cloud.webrisk_v1.types.CreateSubmissionRequest, dict]]):
                 The request object. Request to send a potentially phishy
                 URI to WebRisk.
             parent (:class:`str`):
@@ -663,7 +680,7 @@ class WebRiskServiceAsyncClient:
         Returns:
             google.cloud.webrisk_v1.types.Submission:
                 Wraps a URI that might be displaying
-                phishing content.
+                malicious content.
 
         """
         # Create or coerce a protobuf request object.
@@ -689,7 +706,7 @@ class WebRiskServiceAsyncClient:
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.create_submission,
-            default_timeout=60.0,
+            default_timeout=600.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -717,14 +734,9 @@ class WebRiskServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-webrisk",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebRiskServiceAsyncClient",)
