@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.webrisk_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -59,7 +71,7 @@ class WebRiskServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[WebRiskServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -314,8 +326,8 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, WebRiskServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, WebRiskServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web risk service client.
@@ -329,7 +341,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
             transport (Union[str, WebRiskServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +371,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +424,13 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def compute_threat_list_diff(
         self,
-        request: Union[webrisk.ComputeThreatListDiffRequest, dict] = None,
+        request: Optional[Union[webrisk.ComputeThreatListDiffRequest, dict]] = None,
         *,
-        threat_type: webrisk.ThreatType = None,
-        version_token: bytes = None,
-        constraints: webrisk.ComputeThreatListDiffRequest.Constraints = None,
+        threat_type: Optional[webrisk.ThreatType] = None,
+        version_token: Optional[bytes] = None,
+        constraints: Optional[webrisk.ComputeThreatListDiffRequest.Constraints] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.ComputeThreatListDiffResponse:
         r"""Gets the most recent threat list diffs. These diffs
@@ -446,7 +459,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
                 # Initialize request argument(s)
                 request = webrisk_v1.ComputeThreatListDiffRequest(
-                    threat_type="UNWANTED_SOFTWARE",
+                    threat_type="SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
                 )
 
                 # Make the request
@@ -461,7 +474,9 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
             threat_type (google.cloud.webrisk_v1.types.ThreatType):
                 Required. The threat list to update.
                 Only a single ThreatType should be
-                specified.
+                specified per request. If you want to
+                handle multiple ThreatTypes, you must
+                make one request per ThreatType.
 
                 This corresponds to the ``threat_type`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -539,12 +554,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def search_uris(
         self,
-        request: Union[webrisk.SearchUrisRequest, dict] = None,
+        request: Optional[Union[webrisk.SearchUrisRequest, dict]] = None,
         *,
-        uri: str = None,
-        threat_types: Sequence[webrisk.ThreatType] = None,
+        uri: Optional[str] = None,
+        threat_types: Optional[MutableSequence[webrisk.ThreatType]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchUrisResponse:
         r"""This method is used to check whether a URI is on a
@@ -572,7 +587,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 # Initialize request argument(s)
                 request = webrisk_v1.SearchUrisRequest(
                     uri="uri_value",
-                    threat_types="UNWANTED_SOFTWARE",
+                    threat_types=['SOCIAL_ENGINEERING_EXTENDED_COVERAGE'],
                 )
 
                 # Make the request
@@ -592,7 +607,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 This corresponds to the ``uri`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
+            threat_types (MutableSequence[google.cloud.webrisk_v1.types.ThreatType]):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
@@ -650,12 +665,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def search_hashes(
         self,
-        request: Union[webrisk.SearchHashesRequest, dict] = None,
+        request: Optional[Union[webrisk.SearchHashesRequest, dict]] = None,
         *,
-        hash_prefix: bytes = None,
-        threat_types: Sequence[webrisk.ThreatType] = None,
+        hash_prefix: Optional[bytes] = None,
+        threat_types: Optional[MutableSequence[webrisk.ThreatType]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchHashesResponse:
         r"""Gets the full hashes that match the requested hash
@@ -682,7 +697,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
                 # Initialize request argument(s)
                 request = webrisk_v1.SearchHashesRequest(
-                    threat_types="UNWANTED_SOFTWARE",
+                    threat_types=['SOCIAL_ENGINEERING_EXTENDED_COVERAGE'],
                 )
 
                 # Make the request
@@ -699,12 +714,15 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 A hash prefix, consisting of the most
                 significant 4-32 bytes of a SHA256 hash.
                 For JSON requests, this field is
-                base64-encoded.
+                base64-encoded. Note that if this
+                parameter is provided by a URI, it must
+                be encoded using the web safe base64
+                variant (RFC 4648).
 
                 This corresponds to the ``hash_prefix`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (Sequence[google.cloud.webrisk_v1.types.ThreatType]):
+            threat_types (MutableSequence[google.cloud.webrisk_v1.types.ThreatType]):
                 Required. The ThreatLists to search
                 in. Multiple ThreatLists may be
                 specified.
@@ -762,12 +780,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def create_submission(
         self,
-        request: Union[webrisk.CreateSubmissionRequest, dict] = None,
+        request: Optional[Union[webrisk.CreateSubmissionRequest, dict]] = None,
         *,
-        parent: str = None,
-        submission: webrisk.Submission = None,
+        parent: Optional[str] = None,
+        submission: Optional[webrisk.Submission] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.Submission:
         r"""Creates a Submission of a URI suspected of containing phishing
@@ -776,8 +794,9 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         `Google's Social Engineering
         lists <https://support.google.com/webmasters/answer/6350487/>`__
         in order to protect users that could get exposed to this threat
-        in the future. Only projects with CREATE_SUBMISSION_USERS
-        visibility can use this method.
+        in the future. Only allowlisted projects can use this method
+        during Early Access. Please reach out to Sales or your customer
+        engineer to obtain access.
 
         .. code-block:: python
 
@@ -838,7 +857,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         Returns:
             google.cloud.webrisk_v1.types.Submission:
                 Wraps a URI that might be displaying
-                phishing content.
+                malicious content.
 
         """
         # Create or coerce a protobuf request object.
@@ -899,14 +918,9 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-webrisk",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebRiskServiceClient",)
