@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.webrisk_v1beta1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -59,7 +71,7 @@ class WebRiskServiceV1Beta1ClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[WebRiskServiceV1Beta1Transport]:
         """Returns an appropriate transport class.
 
@@ -314,8 +326,8 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, WebRiskServiceV1Beta1Transport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, WebRiskServiceV1Beta1Transport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the web risk service v1 beta1 client.
@@ -329,7 +341,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
             transport (Union[str, WebRiskServiceV1Beta1Transport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -359,6 +371,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -411,13 +424,13 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
 
     def compute_threat_list_diff(
         self,
-        request: Union[webrisk.ComputeThreatListDiffRequest, dict] = None,
+        request: Optional[Union[webrisk.ComputeThreatListDiffRequest, dict]] = None,
         *,
-        threat_type: webrisk.ThreatType = None,
-        version_token: bytes = None,
-        constraints: webrisk.ComputeThreatListDiffRequest.Constraints = None,
+        threat_type: Optional[webrisk.ThreatType] = None,
+        version_token: Optional[bytes] = None,
+        constraints: Optional[webrisk.ComputeThreatListDiffRequest.Constraints] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.ComputeThreatListDiffResponse:
         r"""Gets the most recent threat list diffs.
@@ -524,12 +537,12 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
 
     def search_uris(
         self,
-        request: Union[webrisk.SearchUrisRequest, dict] = None,
+        request: Optional[Union[webrisk.SearchUrisRequest, dict]] = None,
         *,
-        uri: str = None,
-        threat_types: Sequence[webrisk.ThreatType] = None,
+        uri: Optional[str] = None,
+        threat_types: Optional[MutableSequence[webrisk.ThreatType]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchUrisResponse:
         r"""This method is used to check whether a URI is on a
@@ -553,7 +566,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
                 # Initialize request argument(s)
                 request = webrisk_v1beta1.SearchUrisRequest(
                     uri="uri_value",
-                    threat_types="UNWANTED_SOFTWARE",
+                    threat_types=['UNWANTED_SOFTWARE'],
                 )
 
                 # Make the request
@@ -573,7 +586,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
                 This corresponds to the ``uri`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (Sequence[google.cloud.webrisk_v1beta1.types.ThreatType]):
+            threat_types (MutableSequence[google.cloud.webrisk_v1beta1.types.ThreatType]):
                 Required. The ThreatLists to search
                 in.
 
@@ -630,12 +643,12 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
 
     def search_hashes(
         self,
-        request: Union[webrisk.SearchHashesRequest, dict] = None,
+        request: Optional[Union[webrisk.SearchHashesRequest, dict]] = None,
         *,
-        hash_prefix: bytes = None,
-        threat_types: Sequence[webrisk.ThreatType] = None,
+        hash_prefix: Optional[bytes] = None,
+        threat_types: Optional[MutableSequence[webrisk.ThreatType]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> webrisk.SearchHashesResponse:
         r"""Gets the full hashes that match the requested hash
@@ -662,7 +675,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
 
                 # Initialize request argument(s)
                 request = webrisk_v1beta1.SearchHashesRequest(
-                    threat_types="UNWANTED_SOFTWARE",
+                    threat_types=['UNWANTED_SOFTWARE'],
                 )
 
                 # Make the request
@@ -684,7 +697,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
                 This corresponds to the ``hash_prefix`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            threat_types (Sequence[google.cloud.webrisk_v1beta1.types.ThreatType]):
+            threat_types (MutableSequence[google.cloud.webrisk_v1beta1.types.ThreatType]):
                 Required. The ThreatLists to search
                 in.
 
@@ -753,14 +766,9 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-webrisk",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("WebRiskServiceV1Beta1Client",)
